==> qhacc-0.6.1a.tar.gz: qhacc-0.6.1a/src/qhaccrecwin.h <==
/************************** * * * * * * * * * * * * ***************************
    Copyright (c) 2000 Ryan Bobko
                       ryan@ostrich-emulators.cx

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.     
*************************** * * * * * * * * * * * * **************************/
 
#ifndef _QHACCRECWIZ_H
#define _QHACCRECWIZ_H

#include "transaction.h"

#include <qcolor.h>
#include <qlineedit.h>
#include <qdatetime.h>

class Prefs;
class QLabel;
class Account;
class QHaccRecView;
class QHaccLineEdit;
class QHaccDateEdit;
class QHaccAccountManager;

class QHaccRecWin : public QWidget {
  Q_OBJECT
 public:
  QHaccRecWin( Account * =0, QWidget * =0, const char * =0 );
  ~QHaccRecWin();
  void accountOpened( Account * );

 private:
  QHaccRecView * tView;
  QHaccDateEdit * enddate;
  QHaccLineEdit * obal, * ebal;
  QLabel * lblDiff;
  Account * acct;
  const Prefs * prefs;
  float unsum, origUnsum;
  bool firstRun;

  protected slots:
    void hide();
  void changeDate();
  void changeSums( QHaccVector, float, float );
  void refresh();
  void accept();
  void cancel();
};

#endif

==> qhacc-3.5.tar.gz: qhacc-3.5/src/qhaccrecwin.h <==
/************************** * * * * * * * * * * * * ***************************
    Copyright (c) 1999-2005 Ryan Bobko
                       ryan@ostrich-emulators.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.     
*************************** * * * * * * * * * * * * **************************/
 
#ifndef _QHACCRECWIZ_H
#define _QHACCRECWIZ_H

#include "qhacctablerows.h"

#include <qwidget.h>
#include <qdatetime.h>

class QHacc;
class QLabel;
class QLineEdit;
class QHaccView;
class QHaccRecView;
class QHaccLineEdit;
class QHaccDateEdit;
class QHaccJournalChooser;

class QHaccRecWin : public QWidget {
  Q_OBJECT
 public:
  QHaccRecWin( QHacc *, const Journal&, QWidget * =0, const char * =0 );
  ~QHaccRecWin();
	
	void readPrefs( bool );
	void save();
	
	void setAccount( const Account& );
	QHaccView * getView() const;

 private:
	QHacc * engine;
  QHaccRecView * tView;
  QHaccDateEdit * enddate;
  QHaccLineEdit * ebal;
	QHaccJournalChooser * jchsr;
	QLabel * lblDiff, * lblOBal;
  Account account;
	Journal journal;
	bool fliprevs;

  protected slots:
    void hide();
  void changeDate();
	void changeP( const QString&, int );
	void changeP( const QString&, QString );
	void changeP( const QString&, bool );
  void accept();
  void cancel();
	void refresh();
	void removeA( const Account& );
	void modT( const Transaction& );
	void modA( const Account&, const Account& );
};

#endif
